@@ -25,5 +25,5 @@ class BaseAPIClient(APIClient):
         return super().delete(path, HTTP_ACCEPT=self.ACCEPT_HEADER, **extra)
 
 
-class V1APIClient(BaseAPIClient):
-    ACCEPT_HEADER = "application/vnd.vanoma.api+json; version=1"
+class APIClientV1_0(BaseAPIClient):
+    ACCEPT_HEADER = "application/vnd.vanoma.api+json; version=1.0"
